@@ -1,9 +1,9 @@
 package Net::DNS::RR::DS;
 
 #
-# $Id: DS.pm 1773 2020-03-17 08:40:55Z willem $
+# $Id: DS.pm 1779 2020-05-11 09:11:17Z willem $
 #
-our $VERSION = (qw$LastChangedRevision: 1773 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1779 $)[1];
 
 
 use strict;
@@ -215,20 +215,19 @@ sub babble {
 sub create {
 	my $class = shift;
 	my $keyrr = shift;
-	my %args  = $keyrr->ttl ? ( ttl => $keyrr->ttl, @_ ) : (@_);
+	my %args  = @_;
 
 	my ($type) = reverse split '::', $class;
 
-	my $kname = $keyrr->name;
-	my $flags = $keyrr->flags;
-	croak "Unable to create $type record for non-DNSSEC key" unless $keyrr->protocol == 3;
-	croak "Unable to create $type record for non-authentication key" if $flags & 0x8000;
-	croak "Unable to create $type record for non-ZONE key" unless ( $flags & 0x300 ) == 0x100;
+	croak "Unable to create $type record for non-zone key" unless $keyrr->zone;
+	croak "Unable to create $type record for revoked key" if $keyrr->revoke;
+	croak "Unable to create $type record for invalid key" unless $keyrr->protocol == 3;
 
 	my $self = new Net::DNS::RR(
-		name	  => $kname,				# per definition, same as keyrr
+		owner	  => $keyrr->owner,			# per definition, same as keyrr
 		type	  => $type,
 		class	  => $keyrr->class,
+		ttl	  => $keyrr->{ttl},
 		keytag	  => $keyrr->keytag,
 		algorithm => $keyrr->algorithm,
 		digtype	  => 1,					# SHA1 by default
